@@ -1,6 +1,6 @@
 #ifndef lint
 static const char rcsid[] =
-    "@(#) $Id: cupdate.c 31 2010-09-02 00:57:20Z leres $ (LBL)";
+    "@(#) $Id: cupdate.c 36 2013-11-15 00:08:37Z leres $ (LBL)";
 #endif
 /*
  * Copyright (c) 2005, 2006, 2008, 2009, 2010
@@ -31,11 +31,11 @@ extern const char version[];
 
 /* Forwards */
 char *buildcommand(int, char **);
-void die(const char *, ...) __attribute__((volatile, format (printf, 1, 2)));
+void die(const char *, ...) __attribute__((noreturn, format (printf, 1, 2)));
 void finish(void);
 char *runcommand(char *);
 int trimws(char *, int);
-void usage(void) __attribute__((volatile));
+void usage(void) __attribute__((noreturn));
 
 int
 main(int argc, char **argv)
